{% load markup %}
  {% comment %} short/long text questions {% endcomment %}
  {% if question.explanation %}
      <div class="casesanswerdisplay">
        <a href="#q{{question.id}}" class="moretoggle">Show explanation &gt;&gt;</a>
        <div id="q{{question.id}}" class="toggleable">
          <p>{{question.explanation|markdown}}</p>
        </div>
      </div>
  {% endif %}
