{% extends "base.html" %}
{% load bootstrap %}
{% block content %}

<ul class="breadcrumb">
    <li><a href="{{answer.question.quiz.pageblock.section.get_edit_url}}">{{answer.question.quiz.pageblock.section.label}}</a></li>
    <li><a href="{% url 'edit-quiz' answer.question.quiz.id %}">Edit Quiz</a></li>
    <li>
        <a href="{% url 'edit-question' answer.question.id %}">Edit Question
            {{answer.question.display_number}}: {{ answer.question.text }}
        </a>
    </li>
</ul>


<h2>Answer {{answer.display_number}}: {{ answer.value }}</h2>

<form action="." method="post" class="well form-horizontal" >
<table width="100%">
{{ answer_form|bootstrap}}
</table>
<input type="submit" value="save" class="btn btn-primary" />
</form>

{% endblock %}
