{% load markup %}

{% if block.rhetorical %}
  <textarea rows="10" name="question{{question.id}}" class="form-control"></textarea>
{% else %}
  {% if response %}
    {% if block.allow_redo %}
    <textarea rows="10" name="pageblock-{{block.pageblock.id}}-question{{question.id}}" class="form-control">{{response.value}}</textarea>
    {% else %}
    <p class="yours">{{response.value|markdown}}</p>
    {% endif %}
  {% else %}
    <textarea rows="10" name="pageblock-{{block.pageblock.id}}-question{{question.id}}" class="form-control"></textarea>
  {% endif %}
{% endif %}
